@@ -36,7 +36,7 @@ gmpcPlugin plugin = {
 	/* name */
 	"Statistics",
 	/* version */
-	{0,0,1},
+	{0,15,0},
 	/* type */
 	GMPC_PLUGIN_PL_BROWSER,
 	/* id, set by gmpc */
@@ -68,6 +68,7 @@ enum {
 	SERVERSTATS_MPD_DB_PLAYTIME,
 	SERVERSTATS_MPD_DB_ARTISTS,
 	SERVERSTATS_MPD_DB_ALBUMS,
+  SERVERSTATS_MPD_DB_SONGS,
 	SERVERSTATS_NUM_FIELDS
 };
 static GtkTreeRowReference *serverstats_ref = NULL; 
@@ -126,7 +127,7 @@ static void serverstats_add(GtkWidget *category_tree)
 			PL3_CAT_TYPE, plugin.id,
 			PL3_CAT_TITLE,"Server Statistics", 
 			PL3_CAT_INT_ID, "/",
-			PL3_CAT_ICON_ID, "serverstats-mpd",
+			PL3_CAT_ICON_ID, "mpd",
 			PL3_CAT_PROC, TRUE,
 			PL3_CAT_ICON_SIZE,GTK_ICON_SIZE_DND,-1);
 	/** 
@@ -185,6 +186,10 @@ static void serverstats_update()
 	value = g_strdup_printf("%i", mpd_stats_get_total_albums(connection));
 	gtk_label_set_text(GTK_LABEL(serverstats_labels[SERVERSTATS_MPD_DB_ALBUMS]), value);
 	g_free(value);
+  /** DB SONGS*/
+  value = g_strdup_printf("%i", mpd_stats_get_total_songs(connection));
+  gtk_label_set_text(GTK_LABEL(serverstats_labels[SERVERSTATS_MPD_DB_SONGS]), value);
+  g_free(value);
 }
 
 void serverstats_combo_changed(GtkComboBox *box, GtkWidget *pb)
@@ -391,7 +396,15 @@ static void serverstats_init()
 	label = serverstats_labels[SERVERSTATS_MPD_DB_ALBUMS]= gtk_label_new("");
 	gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
 	gtk_table_attach(GTK_TABLE(table),label, 1,2,7,8,GTK_SHRINK|GTK_FILL, GTK_SHRINK|GTK_FILL, 0,0);	
-
+/** Mpd Songs */
+  label = gtk_label_new("");
+  gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
+  gtk_misc_set_padding(GTK_MISC(label), 12,0);
+  gtk_label_set_markup(GTK_LABEL(label), "<b>Number of songs:</b>");
+  gtk_table_attach(GTK_TABLE(table),label, 0,1,8,9,GTK_SHRINK|GTK_FILL, GTK_SHRINK|GTK_FILL, 0,0);
+  label = serverstats_labels[SERVERSTATS_MPD_DB_SONGS]= gtk_label_new("");
+  gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
+  gtk_table_attach(GTK_TABLE(table),label, 1,2,8,9,GTK_SHRINK|GTK_FILL, GTK_SHRINK|GTK_FILL, 0,0);
 	/**
 	 * Add table
 	 */
@@ -509,11 +522,11 @@ gchar * serverstats_format_time(unsigned long seconds)
 void serverstats_plugin_init(void)
 {
 	gchar *path = NULL;
-	GtkIconSet *set;
+/*	GtkIconSet *set;
 	GtkIconFactory *factory;
 	GdkPixbuf *pb;
 
-	factory = gtk_icon_factory_new ();
+//	factory = gtk_icon_factory_new ();
 	path = g_strdup_printf("%s%c%s%c%s",plugin.path,G_DIR_SEPARATOR, "serverstats",G_DIR_SEPARATOR,"mpd.png");
 	pb = gdk_pixbuf_new_from_file (path ,NULL);
 	set = gtk_icon_set_new_from_pixbuf (pb);
@@ -521,6 +534,10 @@ void serverstats_plugin_init(void)
 	g_free(path);
 	g_object_unref(pb);
 	gtk_icon_factory_add_default (factory);
+*/
+	path = g_strdup_printf("%s%c%s",plugin.path,G_DIR_SEPARATOR, "serverstats");
+	gtk_icon_theme_append_search_path(gtk_icon_theme_get_default (),path);
+	g_free(path);	
 }
 
 void serverstats_connection_changed(MpdObj *mi, int connect,void *usedata)
